@@ -5,10 +5,10 @@
 #                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
 #
 # This file is part of the Kaltura Collaborative Media Suite which allows users
-# to do with audio, video, and animation what Wiki platfroms allow them to do with
+# to do with audio, video, and animation what Wiki platforms allow them to do with
 # text.
 #
-# Copyright (C) 2006-2020  Kaltura Inc.
+# Copyright (C) 2006-2021  Kaltura Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -111,6 +111,7 @@ class KalturaAttachmentAsset(KalturaAsset):
             partnerData=NotImplemented,
             partnerDescription=NotImplemented,
             actualSourceAssetParamsIds=NotImplemented,
+            sizeInBytes=NotImplemented,
             filename=NotImplemented,
             title=NotImplemented,
             format=NotImplemented,
@@ -129,7 +130,8 @@ class KalturaAttachmentAsset(KalturaAsset):
             description,
             partnerData,
             partnerDescription,
-            actualSourceAssetParamsIds)
+            actualSourceAssetParamsIds,
+            sizeInBytes)
 
         # The filename of the attachment asset content
         # @var string
