@@ -5,10 +5,10 @@
 #                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
 #
 # This file is part of the Kaltura Collaborative Media Suite which allows users
-# to do with audio, video, and animation what Wiki platfroms allow them to do with
+# to do with audio, video, and animation what Wiki platforms allow them to do with
 # text.
 #
-# Copyright (C) 2006-2020  Kaltura Inc.
+# Copyright (C) 2006-2021  Kaltura Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -88,6 +88,18 @@ class KalturaCaptionParamsOrderBy(object):
     def getValue(self):
         return self.value
 
+# @package Kaltura
+# @subpackage Client
+class KalturaCaptionSource(object):
+    UNKNOWN = "0"
+    ZOOM = "1"
+
+    def __init__(self, value):
+        self.value = value
+
+    def getValue(self):
+        return self.value
+
 # @package Kaltura
 # @subpackage Client
 class KalturaCaptionType(object):
@@ -122,12 +134,14 @@ class KalturaCaptionAsset(KalturaAsset):
             partnerData=NotImplemented,
             partnerDescription=NotImplemented,
             actualSourceAssetParamsIds=NotImplemented,
+            sizeInBytes=NotImplemented,
             captionParamsId=NotImplemented,
             language=NotImplemented,
             languageCode=NotImplemented,
             isDefault=NotImplemented,
             label=NotImplemented,
             format=NotImplemented,
+            source=NotImplemented,
             status=NotImplemented,
             parentId=NotImplemented,
             accuracy=NotImplemented,
@@ -147,7 +161,8 @@ class KalturaCaptionAsset(KalturaAsset):
             description,
             partnerData,
             partnerDescription,
-            actualSourceAssetParamsIds)
+            actualSourceAssetParamsIds,
+            sizeInBytes)
 
         # The Caption Params used to create this Caption Asset
         # @var int
@@ -176,6 +191,11 @@ class KalturaCaptionAsset(KalturaAsset):
         # @insertonly
         self.format = format
 
+        # The source of the asset
+        # @var KalturaCaptionSource
+        # @insertonly
+        self.source = source
+
         # The status of the asset
         # @var KalturaCaptionAssetStatus
         # @readonly
@@ -206,6 +226,7 @@ class KalturaCaptionAsset(KalturaAsset):
         'isDefault': (KalturaEnumsFactory.createInt, "KalturaNullableBoolean"), 
         'label': getXmlNodeText, 
         'format': (KalturaEnumsFactory.createString, "KalturaCaptionType"), 
+        'source': (KalturaEnumsFactory.createString, "KalturaCaptionSource"), 
         'status': (KalturaEnumsFactory.createInt, "KalturaCaptionAssetStatus"), 
         'parentId': getXmlNodeText, 
         'accuracy': getXmlNodeInt, 
@@ -225,6 +246,7 @@ class KalturaCaptionAsset(KalturaAsset):
         kparams.addIntEnumIfDefined("isDefault", self.isDefault)
         kparams.addStringIfDefined("label", self.label)
         kparams.addStringEnumIfDefined("format", self.format)
+        kparams.addStringEnumIfDefined("source", self.source)
         kparams.addStringIfDefined("parentId", self.parentId)
         kparams.addIntIfDefined("accuracy", self.accuracy)
         kparams.addBoolIfDefined("displayOnPlayer", self.displayOnPlayer)
@@ -264,6 +286,12 @@ class KalturaCaptionAsset(KalturaAsset):
     def setFormat(self, newFormat):
         self.format = newFormat
 
+    def getSource(self):
+        return self.source
+
+    def setSource(self, newSource):
+        self.source = newSource
+
     def getStatus(self):
         return self.status
 
@@ -1332,6 +1360,7 @@ class KalturaCaptionClientPlugin(KalturaClientPlugin):
             'KalturaCaptionAssetStatus': KalturaCaptionAssetStatus,
             'KalturaCaptionAssetOrderBy': KalturaCaptionAssetOrderBy,
             'KalturaCaptionParamsOrderBy': KalturaCaptionParamsOrderBy,
+            'KalturaCaptionSource': KalturaCaptionSource,
             'KalturaCaptionType': KalturaCaptionType,
         }
 
