@@ -5,10 +5,10 @@
 #                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
 #
 # This file is part of the Kaltura Collaborative Media Suite which allows users
-# to do with audio, video, and animation what Wiki platfroms allow them to do with
+# to do with audio, video, and animation what Wiki platforms allow them to do with
 # text.
 #
-# Copyright (C) 2006-2020  Kaltura Inc.
+# Copyright (C) 2006-2021  Kaltura Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -222,7 +222,6 @@ class KalturaCuePoint(KalturaObjectBase):
         self.startTime = startTime
 
         # @var string
-        # @readonly
         self.userId = userId
 
         # @var string
@@ -282,6 +281,7 @@ class KalturaCuePoint(KalturaObjectBase):
         kparams.addIntIfDefined("triggeredAt", self.triggeredAt)
         kparams.addStringIfDefined("tags", self.tags)
         kparams.addIntIfDefined("startTime", self.startTime)
+        kparams.addStringIfDefined("userId", self.userId)
         kparams.addStringIfDefined("partnerData", self.partnerData)
         kparams.addIntIfDefined("partnerSortValue", self.partnerSortValue)
         kparams.addIntEnumIfDefined("forceStop", self.forceStop)
@@ -337,6 +337,9 @@ class KalturaCuePoint(KalturaObjectBase):
     def getUserId(self):
         return self.userId
 
+    def setUserId(self, newUserId):
+        self.userId = newUserId
+
     def getPartnerData(self):
         return self.partnerData
 
