@@ -5,10 +5,10 @@
 #                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
 #
 # This file is part of the Kaltura Collaborative Media Suite which allows users
-# to do with audio, video, and animation what Wiki platfroms allow them to do with
+# to do with audio, video, and animation what Wiki platforms allow them to do with
 # text.
 #
-# Copyright (C) 2006-2020  Kaltura Inc.
+# Copyright (C) 2006-2021  Kaltura Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -148,6 +148,9 @@ class KalturaExternalMediaEntry(KalturaMediaEntry):
             capabilities=NotImplemented,
             templateEntryId=NotImplemented,
             displayInSearch=NotImplemented,
+            application=NotImplemented,
+            applicationVersion=NotImplemented,
+            blockAutoTranscript=NotImplemented,
             plays=NotImplemented,
             views=NotImplemented,
             lastPlayedAt=NotImplemented,
@@ -159,6 +162,7 @@ class KalturaExternalMediaEntry(KalturaMediaEntry):
             mediaType=NotImplemented,
             conversionQuality=NotImplemented,
             sourceType=NotImplemented,
+            sourceVersion=NotImplemented,
             searchProviderType=NotImplemented,
             searchProviderId=NotImplemented,
             creditUserName=NotImplemented,
@@ -216,6 +220,9 @@ class KalturaExternalMediaEntry(KalturaMediaEntry):
             capabilities,
             templateEntryId,
             displayInSearch,
+            application,
+            applicationVersion,
+            blockAutoTranscript,
             plays,
             views,
             lastPlayedAt,
@@ -227,6 +234,7 @@ class KalturaExternalMediaEntry(KalturaMediaEntry):
             mediaType,
             conversionQuality,
             sourceType,
+            sourceVersion,
             searchProviderType,
             searchProviderId,
             creditUserName,
