@@ -5,10 +5,10 @@
 #                          |_|\_\__,_|_|\__|\_,_|_| \__,_|
 #
 # This file is part of the Kaltura Collaborative Media Suite which allows users
-# to do with audio, video, and animation what Wiki platfroms allow them to do with
+# to do with audio, video, and animation what Wiki platforms allow them to do with
 # text.
 #
-# Copyright (C) 2006-2020  Kaltura Inc.
+# Copyright (C) 2006-2021  Kaltura Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -700,6 +700,7 @@ class KalturaHttpNotificationDispatchJobData(KalturaEventNotificationDispatchJob
             contentParameters=NotImplemented,
             url=NotImplemented,
             method=NotImplemented,
+            contentType=NotImplemented,
             data=NotImplemented,
             timeout=NotImplemented,
             connectTimeout=NotImplemented,
@@ -729,6 +730,10 @@ class KalturaHttpNotificationDispatchJobData(KalturaEventNotificationDispatchJob
         # @var KalturaHttpNotificationMethod
         self.method = method
 
+        # The type of the data to send.
+        # @var string
+        self.contentType = contentType
+
         # Data to send.
         # @var string
         self.data = data
@@ -803,6 +808,7 @@ class KalturaHttpNotificationDispatchJobData(KalturaEventNotificationDispatchJob
     PROPERTY_LOADERS = {
         'url': getXmlNodeText, 
         'method': (KalturaEnumsFactory.createInt, "KalturaHttpNotificationMethod"), 
+        'contentType': getXmlNodeText, 
         'data': getXmlNodeText, 
         'timeout': getXmlNodeInt, 
         'connectTimeout': getXmlNodeInt, 
@@ -831,6 +837,7 @@ class KalturaHttpNotificationDispatchJobData(KalturaEventNotificationDispatchJob
         kparams.put("objectType", "KalturaHttpNotificationDispatchJobData")
         kparams.addStringIfDefined("url", self.url)
         kparams.addIntEnumIfDefined("method", self.method)
+        kparams.addStringIfDefined("contentType", self.contentType)
         kparams.addStringIfDefined("data", self.data)
         kparams.addIntIfDefined("timeout", self.timeout)
         kparams.addIntIfDefined("connectTimeout", self.connectTimeout)
@@ -862,6 +869,12 @@ class KalturaHttpNotificationDispatchJobData(KalturaEventNotificationDispatchJob
     def setMethod(self, newMethod):
         self.method = newMethod
 
+    def getContentType(self):
+        return self.contentType
+
+    def setContentType(self, newContentType):
+        self.contentType = newContentType
+
     def getData(self):
         return self.data
 
